% disp_fault_incl_main
%
% Integrates the Green's functions g_x, g_y, g_xx, g_yy and g_xy to obtain G_x, G_y, G_xx, G_yy
% and G_xy which represent scaled displacements u_x/D and u_y/D and scaled stresses sigma_xx/C,
% sigma_yy/C and sigma_xy/C respectively, and plots the results as image plots and line plots
% (cross sections for fixed x or y values). The integrations are performed analytically over a
% rectangular reservoir domain crossed by an inclined displaced fault.
%
% In addition, generates various other plots and results. 
%
% Jan Dirk Jansen, TU Delft, August 2018 - June 2019
% j.d.jansen@tudelft.nl
%

clear vars
close all

% Enter reservoir parameters: (Note: all SI units are for a 2D configuration)
alpha = 0.9; % Biot's coefficient 
G = 6.5e9; % shear modulus, Pa  
mu = 0.60; % friction coefficient
nu = 0.15; % Poisson's ratio, -
p = 20e6; % incremental pressure, Pa
p_0 = 35e6; % initial pressure, Pa 

% Enter fault dip in rad; positive values correspond to a normal fault.
theta = pi/2; % 90 degree; vertical fault (Used for figures in the paper)
% theta = pi/3; % 60 degree; normal fault (NOT used for figures in the paper) 
% theta = 2*pi/3; % 120 degree; reversed fault (NOT used for figures in the paper)
% For inclined-fault figures in the paper (Section 9), see Matlab main file
% disp_fault_num_check_main
sigma_xx_0 = -60e6; % initial horizontal stress, N/m
sigma_xy_0 = 15e6; % initial shear stress, N/m

% Define numerical values to plot examples:
a = 100; % [m]
b = 200; % [m]
c = inf; % [m] Note: only use c = d = inf; just choosing one of them as inf will not work
d = inf; % [m]
% c = 1000; % [m]
% d = 2000; % [m]

% Define parameters for image plots:
x_plot_min = -400; % [m]
x_plot_max =  400; % [m]
y_plot_min = -300; % [m]
y_plot_max =  300; % [m]

% x_plot_min = 0; % [m]
% x_plot_max = 160; % [m]
% y_plot_min = 90; % [m]
% y_plot_max = 210; % [m]

n_pt_x = 500; % [-]
n_pt_y = 400; % [-]
n_pt_y_2 = 30000; % [-] higher resolution (gives higher peaks for shear stresses);
Dx = (x_plot_max - x_plot_min)/n_pt_x; % [m]
Dy = (y_plot_max - y_plot_min)/n_pt_y; % [m]
Dy_2 = (y_plot_max - y_plot_min)/n_pt_y_2; % [m]

% Define plot locations of constant x and y values for cross-sectional plots:
X_1 = -200; % [m] 
X_2 = 1e-6; % [m]
X_3 = 200; % [m]
Y_1 = -150; % [m] 
Y_2 = 1e-6; % [m]
Y_3 = 150; % [m]

% Perform checks and set flag for infinite reservoir boundaries:
if a < 0 || b < 0 || c < 0 || d < 0
    error('Parameters a, b, c and d should all be positive or zero.');
end
% Note: this doesn't concern a fundamental limitation of the theory but rather a practical
% limitation to simpify the plotting and the annotations. 

if c == inf || d == inf
    if c == inf && d == inf
        flag_inf = 1; % infinite boundaries
    else
        error('Both boundaries should either be finite or infinite.');
    end
else
    flag_inf = 0; % finite boundaries
end

if theta == pi/2
    flag_vert = 1; % vertical fault
else
    flag_vert = 0; % inclined fault
end

% Compute coefficients and auxiliary variables:
D = (1-2*nu)*alpha*p / (2*pi*(1-nu)*G) % coefficient for displacements, - 
C = G*D % coefficient for stresses, N/m
sigma_xx_eff_0 = sigma_xx_0 + alpha*p_0 % initial effective horizontal stress, N/m
G_xx_eff_0 = sigma_xx_eff_0 / C % dimensionless initial effective horizontal stress, -
G_xy_0 = sigma_xy_0 / C % dimensionless initial shear stress, -
h = a+b; % reservoir height, m
t = b-a; % fault throw, m
M = C*pi*h*t % seismic moment, Nm 

% Create image plots for elastic deformations and stresses:
disp_fault_plot_images(a,b,c,d,Dx,Dy,flag_inf,flag_vert,n_pt_x,n_pt_y,theta,x_plot_max,...
    x_plot_min,y_plot_max,y_plot_min)

if flag_vert == 1 % these plots have only been implemented for vertical faults 
    % Create cross-sectional plots (constant y values):
    disp_fault_plot_const_y(a,b,c,d,Dx,flag_inf,n_pt_x,x_plot_min,Y_1,Y_2,Y_3)
    
    % Create cross-sectional plots (constant x values):
    disp_fault_plot_const_x(a,b,c,d,Dy,flag_inf,n_pt_y,y_plot_min,X_1,X_2,X_3)

    % Create Coulomb stress plots for elastic deformations and stresses:
    disp_fault_plot_Coulomb(a,b,C,Dy_2,mu,n_pt_y_2,nu,sigma_xx_eff_0,...
    sigma_xy_0,y_plot_min)
end

% Create valley plot and parameters:
[p_val,y_1,y_2,y_3,y_4] = valley(a,alpha,b,C,mu,nu,sigma_xx_eff_0,sigma_xy_0);

% Compute and plot excess shear force:
shear_force(a,alpha,b,C,mu,nu,p_0,p_val,sigma_xx_0,sigma_xy_0)
