% syms_vert_g_x_main
%
% Integrates the Green's function g_x to obtain G_x which represents scaled displacement
% u_x/C_hat and plots the result. The integration is performed analytically over a rectangular
% reservoir domain crossed by a vertical displaced fault.  
%
% Jan Dirk Jansen, TU Delft, August 2018
%

clear vars
close all

% Define numerical values to plot examples:
A = 10; % [m]
B = 20; % [m]
C = 1000; % [m]
D = 2000; % [m]
% C = inf; % [m] Note: only use C = D = inf; just choosing one of them as inf will not work
% D = inf; % [m]

% Define plot locations (vertical and horizontal lines):
X_1 = -1500; % [m] 
X_2 = 1e-6; % [m]
X_3 = 2500; % [m]
Y_1 = -1500; % [m] 
Y_2 = 1e-6; % [m]
Y_3 = 1500; % [m]
% X_1 = -40; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 40; % [m]
% Y_1 = -30; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 30; % [m]

% Define plot parameters:
x_plot_min = -1500; % [m]
x_plot_max =  2500; % [m]
y_plot_min = -1500; % [m]
y_plot_max =  1500; % [m]
% x_plot_min = -40; % [m]
% x_plot_max =  40; % [m]
% y_plot_min = -30; % [m]
% y_plot_max =  30; % [m]
n_pt_x = 500; % [-]
n_pt_y = 400; % [-]
Dx = (x_plot_max - x_plot_min)/n_pt_x; % [m]
Dy = (y_plot_max - y_plot_min)/n_pt_y; % [m]

% Perform checks and set flag for infinite reservoir boundaries:
if A < 0 || B < 0 || C < 0 || D < 0
    error('Parameters A, B, C and D should all be positive.');
end
 
if C == inf || D == inf
    if C == inf && D == inf
        flag_inf = 1; % infinite boundaries
    else
        error('Both boundaries should either be finite or infinite.');
    end
else
    flag_inf = 0; % finite boundaries
end

% Compute the integrals symbolically:
syms a b c d x y zeta xi 
gx = (x-zeta) / (2*( (x-zeta)^2 + (y-xi)^2 ) ); % Green's function g_x, [1/m]

% Part I (rectangular part, left of fault):
g1x1 = int(gx,zeta);
g2x1 = simplify(subs(g1x1,zeta,0) - subs(g1x1,zeta,-c),'Steps',10);
g3x1 = int(g2x1,xi);
g4x1 = simplify(subs(g3x1,xi,a) - subs(g3x1,xi,-b),'Steps',10)

% Part IV (rectangular part, right of fault):
g1x4 = int(gx,zeta);
g2x4 = simplify(subs(g1x4,zeta,d) - subs(g1x4,zeta,0),'Steps',10);
g3x4 = int(g2x4,xi);
g4x4 = simplify(subs(g3x4,xi,b) - subs(g3x4,xi,-a),'Steps',10)

% Substitute numerical values:
g5x1 = subs(g4x1,a,A);
g6x1 = subs(g5x1,b,B);
g7x1 = subs(g6x1,c,C);
g8x1 = subs(g7x1,x,X_2);

g5x4 = subs(g4x4,a,A);
g6x4 = subs(g5x4,b,B);
g7x4 = subs(g6x4,d,D);
g8x4 = subs(g7x4,x,X_2);

G_x_sym = g8x1 + g8x4;
clear a b c d x y zeta xi

% Set numerical values:
a = A;
b = B;
c = C;
d = D;

% Create cross-sectional plots (constant y values):
x = zeros(n_pt_x,1);
G_x_plot_1 = zeros(n_pt_x,1);
G_x_plot_2 = zeros(n_pt_x,1);
G_x_plot_3 = zeros(n_pt_x,1);
G_x_plot_1_limit_inf = zeros(n_pt_x,1);
G_x_plot_1_limit_min_inf = zeros(n_pt_x,1);
G_x_plot_2_limit_inf = zeros(n_pt_x,1);
G_x_plot_2_limit_min_inf = zeros(n_pt_x,1);
G_x_plot_3_limit_inf = zeros(n_pt_x,1);
G_x_plot_3_limit_min_inf = zeros(n_pt_x,1);
for i = 1:n_pt_x
    x(i) = x_plot_min + (i-1)*Dx;
    y = Y_1;
    if flag_inf == 1
        G_x_plot_1(i) = Green_vert_g_x_inf(a,b,x(i),y); % limit for infinite reservoir
    else        
        G_x_plot_1(i) = Green_vert_g_x(a,b,c,d,x(i),y);
    end
% % %     G_x_plot_1_limit_inf(i) = (pi/2) * (abs(y+a)-abs(y-b)); 
% % %     G_x_plot_1_limit_min_inf(i) = (pi/2) * (abs(y+b)-abs(y-a));
    y = Y_2;
    if flag_inf == 1
        G_x_plot_2(i) = Green_vert_g_x_inf(a,b,x(i),y); % limit for infinite reservoir
    else        
        G_x_plot_2(i) = Green_vert_g_x(a,b,c,d,x(i),y);
    end
% % %     G_x_plot_2_limit_inf(i) = (pi/2) * (abs(y+a)-abs(y-b)); 
% % %     G_x_plot_2_limit_min_inf(i) = (pi/2) * (abs(y+b)-abs(y-a)); 
    y = Y_3;
    if flag_inf == 1
        G_x_plot_3(i) = Green_vert_g_x_inf(a,b,x(i),y); % limit for infinite reservoir
    else        
        G_x_plot_3(i) = Green_vert_g_x(a,b,c,d,x(i),y);
    end
% % %     G_x_plot_3_limit_inf(i) = (pi/2) * (abs(y+a)-abs(y-b)); 
% % %     G_x_plot_3_limit_min_inf(i) = (pi/2) * (abs(y+b)-abs(y-a)); 
end

% % % plot(x,G_x_plot_1_limit_inf,'--k','LineWidth',1) 
% % % hold on
% % % plot(x,G_x_plot_1_limit_min_inf,'--k','LineWidth',1) 
% % % plot(x,G_x_plot_2_limit_inf,'--k','LineWidth',1) 
% % % plot(x,G_x_plot_2_limit_min_inf,'--k','LineWidth',1) 
% % % plot(x,G_x_plot_3_limit_inf,'--k','LineWidth',1) 
% % % plot(x,G_x_plot_3_limit_min_inf,'--k','LineWidth',1) 
plot(x,G_x_plot_1,'-r','LineWidth',2)
hold on % % %
plot(x,G_x_plot_2,'-r','LineWidth',2)
plot(x,G_x_plot_3,'-r','LineWidth',2)
hold off
xlabel('\itx')
ylabel('\itG_x')
% title('\it G_x')

% Create cross-sectional plots (constant x values):
clear x y
y = zeros(n_pt_y,1);
G_x_plot_4 = zeros(n_pt_y,1);
G_x_plot_5 = zeros(n_pt_y,1);
G_x_plot_6 = zeros(n_pt_y,1);
G_x_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_x_plot_4(i) = Green_vert_g_x_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_x_plot_4(i) = Green_vert_g_x(a,b,c,d,x,y(i));
    end
    x = X_2;
    if flag_inf == 1
        G_x_plot_5(i) = Green_vert_g_x_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_x_plot_5(i) = Green_vert_g_x(a,b,c,d,x,y(i));
    end
    x = X_3;
    if flag_inf == 1
        G_x_plot_6(i) = Green_vert_g_x_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_x_plot_6(i) = Green_vert_g_x(a,b,c,d,x,y(i));
    end
% % %    G_x_plot_limit_0(i) = (pi/4) * (abs(y(i)+a)-abs(y(i)-a)-abs(y(i)-b)+abs(y(i)+b));  
end

figure
plot(y,G_x_plot_4,'-r','LineWidth',2)
hold on
plot(y,G_x_plot_5,'-r','LineWidth',6)
plot(y,G_x_plot_6,'-r','LineWidth',2)
% % % plot(y,G_x_plot_limit_0,'--k','LineWidth',1) % g_x at x = 0
fplot(G_x_sym,[y_plot_min,y_plot_max],'LineWidth',2) % Matlab symbolic plot results (slow!); only works
                                                     % for non-swapped x and y axis.
hold off
xlabel('\itg_x')
ylabel('\ity')
title('\rm\it G_x')

% Create image plot:
clear x y 
G_x_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
for i = 1:n_pt_x
    x = x_plot_min + (i-1)*Dx;
    for j = 1:n_pt_y
        y = y_plot_min + (j-1)*Dy;
        if flag_inf == 1
            G_x_image(j,i) = Green_vert_g_x_inf(a,b,x,y); % limit for infinite reservoir
        else
            G_x_image(j,i) = Green_vert_g_x(a,b,c,d,x,y); 
        end    
    end
end
figure
x = [x_plot_min x_plot_max];
y = [y_plot_min y_plot_max];
% clims = [-50 50];
% imagesc(x,-y,G_x_image,clims)
imagesc(x,-y,G_x_image)
colorbar
axis off
xlabel('\it x\rm (m)')
ylabel('\it y\rm (m)')
title('\rm\it G_x')
ax1 = gca;
ax2 = axes('Position',get(ax1,'Position'),...
    'XAxisLocation','bottom',...
    'YAxisLocation','left',...
    'Color','none');
axis([x_plot_min x_plot_max y_plot_min y_plot_max])
box on
xlabel('\it x\rm (m)')
ylabel('\it y\rm (m)')
line([0 D],[B B],'Color','k') % contour of reservoir, top right
line([-0 D],[-A -A],'Color','k') % bottom right
line([D D],[-A B],'Color','k') % right
line([-C 0],[A A],'Color','k') % top left
line([-C 0],[-B -B],'Color','k') % bottom left
line([-C -C],[-B A],'Color','k') % left
line([0 0],[y_plot_min y_plot_max],'Color','k','LineWidth',1) % fault

