% syms_vert_g_y_main
%
% Integrates the Green's function g_y to obtain G_y which represents scaled displacement
% u_y/C_hat and plots the result. The integration is performed analytically over a rectangular
% reservoir domain crossed by a vertical displaced fault.  
%
% Jan Dirk Jansen, TU Delft, August 2018
%

clear vars
close all

% Define numerical values to plot examples:
A = 10; % [m]
B = 20; % [m]
C = 1000; % [m]
D = 2000; % [m]
% C = inf; % [m] Note: only use C = D = inf; just choosing one of them as inf will not work
% D = inf; % [m]

% Define plot locations (vertical and horizontal lines):
% X_1 = -1500; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 2500; % [m]
% Y_1 = -1500; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 1500; % [m]

X_1 = -40; % [m] 
X_2 = 1e-6; % [m]
X_3 = 40; % [m]
Y_1 = -30; % [m] 
Y_2 = 1e-6; % [m]
Y_3 = 30; % [m]

% X_1 = -1500; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 2500; % [m]
% Y_1 = -30; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 30; % [m]

% X_1 = -990; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 1990; % [m]
% Y_1 = -19; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 19; % [m]

% Define plot parameters:
% x_plot_min = -1500; % [m]
% x_plot_max =  2500; % [m]
% y_plot_min = -1500; % [m]
% y_plot_max =  1500; % [m]

x_plot_min = -40; % [m]
x_plot_max =  40; % [m]
y_plot_min = -30; % [m]
y_plot_max =  30; % [m]

% x_plot_min = -1500; % [m]
% x_plot_max =  2500; % [m]
% y_plot_min = -30; % [m]
% y_plot_max =  30; % [m]

n_pt_x = 500; % [-]
n_pt_y = 400; % [-]
Dx = (x_plot_max - x_plot_min)/n_pt_x; % [m]
Dy = (y_plot_max - y_plot_min)/n_pt_y; % [m]

% Perform checks and set flag for infinite reservoir boundaries:
if A < 0 || B < 0 || C < 0 || D < 0
    error('Parameters A, B, C and D should all be positive.');
end
 
if C == inf || D == inf
    if C == inf && D == inf
        flag_inf = 1; % infinite boundaries
    else
        error('Both boundaries should either be finite or infinite.');
    end
else
    flag_inf = 0; % finite boundaries
end

% Compute the integrals symbolically:
syms a b c d x y zeta xi 
gy = (y-xi) / (2*( (x-zeta)^2 + (y-xi)^2 ) ); % Green's function g_y, [1/m]

% Part I (rectangular part, left of fault):
g1y1 = int(gy,zeta);
g2y1 = simplify(subs(g1y1,zeta,0) - subs(g1y1,zeta,-c),'Steps',10);
g3y1 = int(g2y1,xi);
g4y1 = simplify(subs(g3y1,xi,a) - subs(g3y1,xi,-b),'Steps',10)

% Part IV (rectangular part, right of fault):
g1y4 = int(gy,zeta);
g2y4 = simplify(subs(g1y4,zeta,d) - subs(g1y4,zeta,0),'Steps',10);
g3y4 = int(g2y4,xi);
g4y4 = simplify(subs(g3y4,xi,b) - subs(g3y4,xi,-a),'Steps',10)

% Substitute numerical values:
g5y1 = subs(g4y1,a,A);
g6y1 = subs(g5y1,b,B);
g7y1 = subs(g6y1,c,C);
g8y1 = subs(g7y1,x,X_2);

g5y4 = subs(g4y4,a,A);
g6y4 = subs(g5y4,b,B);
g7y4 = subs(g6y4,d,D);
g8y4 = subs(g7y4,x,X_2);

G_y_sym = g8y1 + g8y4;

clear a b c d x y zeta xi

% Set numerical values:
a = A;
b = B;
c = C;
d = D;

% Create cross-sectional plots (constant y values):
x = zeros(n_pt_x,1);
G_y_plot_1 = zeros(n_pt_x,1);
G_y_plot_2 = zeros(n_pt_x,1);
G_y_plot_3 = zeros(n_pt_x,1);
G_y_plot_1_limit_inf = zeros(n_pt_x,1);
G_y_plot_1_limit_min_inf = zeros(n_pt_x,1);
G_y_plot_2_limit_inf = zeros(n_pt_x,1);
G_y_plot_2_limit_min_inf = zeros(n_pt_x,1);
G_y_plot_3_limit_inf = zeros(n_pt_x,1);
G_y_plot_3_limit_min_inf = zeros(n_pt_x,1);
for i = 1:n_pt_x
    x(i) = x_plot_min + (i-1)*Dx;
    y = Y_1;
    if flag_inf == 1
        G_y_plot_1(i) = Green_vert_g_y_inf(a,b,x(i),y); % limit for infinite reservoir
    else        
        G_y_plot_1(i) = Green_vert_g_y(a,b,c,d,x(i),y);
    end
    G_y_plot_1_limit_inf(i) = (pi/2) * (abs(y+a)-abs(y-b)); 
    G_y_plot_1_limit_min_inf(i) = (pi/2) * (abs(y+b)-abs(y-a));
    y = Y_2;
    if flag_inf == 1
        G_y_plot_2(i) = Green_vert_g_y_inf(a,b,x(i),y); % limit for infinite reservoir
    else        
        G_y_plot_2(i) = Green_vert_g_y(a,b,c,d,x(i),y);
    end
    G_y_plot_2_limit_inf(i) = (pi/2) * (abs(y+a)-abs(y-b)); 
    G_y_plot_2_limit_min_inf(i) = (pi/2) * (abs(y+b)-abs(y-a)); 
    y = Y_3;
    if flag_inf == 1
        G_y_plot_3(i) = Green_vert_g_y_inf(a,b,x(i),y); % limit for infinite reservoir
    else        
        G_y_plot_3(i) = Green_vert_g_y(a,b,c,d,x(i),y);
    end
    G_y_plot_3_limit_inf(i) = (pi/2) * (abs(y+a)-abs(y-b)); 
    G_y_plot_3_limit_min_inf(i) = (pi/2) * (abs(y+b)-abs(y-a)); 
end

plot(x,G_y_plot_1_limit_inf,'--k','LineWidth',1) 
hold on
plot(x,G_y_plot_1_limit_min_inf,'--k','LineWidth',1) 
plot(x,G_y_plot_2_limit_inf,'--k','LineWidth',1) 
plot(x,G_y_plot_2_limit_min_inf,'--k','LineWidth',1) 
plot(x,G_y_plot_3_limit_inf,'--k','LineWidth',1) 
plot(x,G_y_plot_3_limit_min_inf,'--k','LineWidth',1) 
plot(x,G_y_plot_1,'-b','LineWidth',2)
plot(x,G_y_plot_2,'-r','LineWidth',2)
plot(x,G_y_plot_3,'-g','LineWidth',2)
hold off
xlabel('\itx')
ylabel('\itG_y')
title('\rm\it G_y')
% legend('\ity \rm= -19 m','\ity \rm= 1e-6 m','\ity \rm= 19 m',' Limiting values','Location','northeast')

% Create cross-sectional plots (constant x values):
clear x y
y = zeros(n_pt_y,1);
G_y_plot_4 = zeros(n_pt_y,1);
G_y_plot_5 = zeros(n_pt_y,1);
G_y_plot_6 = zeros(n_pt_y,1);
G_y_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_y_plot_4(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_4(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    x = X_2;
    if flag_inf == 1
        G_y_plot_5(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_5(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    x = X_3;
    if flag_inf == 1
        G_y_plot_6(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_6(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    G_y_plot_limit_0(i) = (pi/4) * (abs(y(i)+a)-abs(y(i)-a)-abs(y(i)-b)+abs(y(i)+b));  
end
figure
plot(y,G_y_plot_4,'-b','LineWidth',2)
hold on
plot(y,G_y_plot_5,'-r','LineWidth',6)
plot(y,G_y_plot_6,'-g','LineWidth',2)
plot(y,G_y_plot_limit_0,':k','LineWidth',6) % g_y at x = 0
fplot(G_y_sym,[y_plot_min,y_plot_max],'LineWidth',2) % Matlab symbolic plot results (slow!); only works
                                                     % for non-swapped x and y axis.
hold off
xlabel('\itG_y')
ylabel('\ity')
title('\rm\it G_y')
% legend('\itx \rm= -990 m','\itx \rm= 1e-6 m','\itx \rm= 1990 m','\itx \rm= 0 m; infinite reservoir','Location','southeast')

% Create image plot:
clear x y
G_y_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
for i = 1:n_pt_x
    x = x_plot_min + (i-1)*Dx;
    for j = 1:n_pt_y
        y = y_plot_min + (j-1)*Dy;
        if flag_inf == 1
            G_y_image(j,i) = Green_vert_g_y_inf(a,b,x,y); % limit for infinite reservoir
        else
            G_y_image(j,i) = Green_vert_g_y(a,b,c,d,x,y); 
        end    
    end
end
figure
x = [x_plot_min x_plot_max];
y = [y_plot_min y_plot_max];
% clims = [-80 80];
% imagesc(x,-y,G_y_image,clims)
imagesc(x,-y,G_y_image)
colorbar
axis off
xlabel('\it x\rm (m)')
ylabel('\it y\rm (m)')
title('\rm\it G_y')
ax1 = gca;
ax2 = axes('Position',get(ax1,'Position'),...
    'XAxisLocation','bottom',...
    'YAxisLocation','left',...
    'Color','none');
axis([x_plot_min x_plot_max y_plot_min y_plot_max])
box on
xlabel('\it x\rm (m)')
ylabel('\it y\rm (m)')
line([0 D],[B B],'Color','k') % contour of reservoir, top right
line([-0 D],[-A -A],'Color','k') % bottom right
line([D D],[-A B],'Color','k') % right
line([-C 0],[A A],'Color','k') % top left
line([-C 0],[-B -B],'Color','k') % bottom left
line([-C -C],[-B A],'Color','k') % left
line([0 0],[y_plot_min y_plot_max],'Color','k','LineWidth',1) % fault
